apiserver

package
v0.0.0-...-f5bcdd4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 24, 2023 License: Apache-2.0 Imports: 25 Imported by: 0

Documentation

Index

Constants

const (
	// APIServerAudience defines the value of jwt audience field.
	APIServerAudience = "iam.api.marmotedu.com"

	// APIServerIssuer defines the value of jwt issuer field.
	APIServerIssuer = "iam-apiserver"
)

Variables

This section is empty.

Functions

func NewApp

func NewApp(basename string) *app.App

NewApp creates an App object with default parameters.

func Run

func Run(cfg *config.Config) error

Run runs the specified APIServer. This should never exit.

Types

type ExtraConfig

type ExtraConfig struct {
	Addr       string
	MaxMsgSize int
	// contains filtered or unexported fields
}

ExtraConfig defines extra configuration for the iam-apiserver.

func (*ExtraConfig) Complete

func (c *ExtraConfig) Complete() *completedExtraConfig

Complete fills in any fields not set that are required to have valid data and can be derived from other fields.

Directories

Path Synopsis
controller

Jump to