Documentation
¶
Index ¶
Constants ¶
const ( // APIServerAudience defines the value of jwt audience field. APIServerAudience = "iam.api.marmotedu.com" // APIServerIssuer defines the value of jwt issuer field. APIServerIssuer = "iam-apiserver" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ExtraConfig ¶
ExtraConfig defines extra configuration for the iam-apiserver.
func (*ExtraConfig) Complete ¶
func (c *ExtraConfig) Complete() *completedExtraConfig
Complete fills in any fields not set that are required to have valid data and can be derived from other fields.
Click to show internal directories.
Click to hide internal directories.