Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WordSepNormalizeFunc ¶
func WordSepNormalizeFunc(_ *pflag.FlagSet, name string) pflag.NormalizedName
WordSepNormalizeFunc changes all flags that contain "_" separators.
Types ¶
type App ¶
type App struct {
// contains filtered or unexported fields
}
App is the main structure of a cli application.
func NewApp ¶
NewApp creates a new application instance based on the given application name, binary name, and other options.
func (*App) AddCommand ¶
AddCommand adds sub command to the application.
func (*App) AddCommands ¶
AddCommands adds multiple sub commands to the application.
type CliOptions ¶
type CliOptions interface {
Flags() (fss NamedFlagSets)
Validate() []error
}
type Command ¶
type Command struct {
// contains filtered or unexported fields
}
Command is a sub command structure of a cli application.
func NewCommand ¶
func NewCommand(usage string, desc string, opts ...CommandOption) *Command
NewCommand creates a new sub command instance based on the given command name and other options.
func (*Command) AddCommand ¶
AddCommand adds sub command to the current command.
func (*Command) AddCommands ¶
AddCommands adds multiple sub commands to the current command.
type CommandOption ¶
type CommandOption func(*Command)
CommandOption defines optional parameters for initializing the command structure.
func WithCommandOptions ¶
func WithCommandOptions(opt CliOptions) CommandOption
WithCommandOptions to open the application's function to read from the command line.
func WithCommandRunFunc ¶
func WithCommandRunFunc(run RunCommandFunc) CommandOption
WithCommandRunFunc is used to set the application's command startup callback function option.
type CompletableOptions ¶
type CompletableOptions interface {
Complete() error
}
CompletableOptions abstracts options which can be completed.
type NamedFlagSets ¶
NamedFlagSets stores named flag sets in the order of calling FlagSet.
type Option ¶
type Option func(app *App)
Option defines optional parameters for initializing the application structure.
func WithDefaultValidArgs ¶
func WithDefaultValidArgs() Option
WithDefaultValidArgs set default validation function to valid non-flag arguments.
func WithDescription ¶
WithDescription is used to set the description of the application.
func WithNoConfig ¶
func WithNoConfig() Option
WithNoConfig set the application does not provide configs flag.
func WithNoVersion ¶
func WithNoVersion() Option
WithNoVersion set the application does not provide version flag.
func WithOptions ¶
func WithOptions(opt CliOptions) Option
WithOptions to open the application's function to read from the command line or read parameters from the configuration file.
func WithRunFunc ¶
WithRunFunc is used to set the application startup callback function option.
func WithSilence ¶
func WithSilence() Option
WithSilence sets the application to silent mode, in which the program startup information, configuration information, and version information are not printed in the console.
func WithValidArgs ¶
func WithValidArgs(args cobra.PositionalArgs) Option
WithValidArgs set the validation function to valid non-flag arguments.
type PrintableOptions ¶
type PrintableOptions interface {
String() string
}
PrintableOptions abstracts options which can be printed.
type RunCommandFunc ¶
RunCommandFunc defines the application's command startup callback function.